@@ -10,7 +10,8 @@ from django.urls import reverse
 import datetime, importlib, os, sys
 
 from .models import GOStatus
-from .utils import generate_xlsx, get_params_for_search, apply_translations
+from .utils import generate_xlsx, get_params_for_search, apply_translations, \
+        apply_field_updates
 
 # Create your views here.
 
@@ -18,7 +19,8 @@ from .utils import generate_xlsx, get_params_for_search, apply_translations
 def general_obj_new(request, Obj, ObjForm, translations={}, \
         callback_prevalidation=False, callback_postvalidation=False, \
         callback_postaction=False, callback_postsaveaction=False, \
-        cancel_url=False, return_url=False, html_scripts=False, *args, **kwargs):
+        cancel_url=False, return_url=False, html_scripts=False, \
+        treat_as_list=False, *args, **kwargs):
     """General form view for adding new objects
     
     It' s not a real view, rather a generic function to creating new objects with the predefined parameters:
@@ -32,8 +34,20 @@ def general_obj_new(request, Obj, ObjForm, translations={}, \
     ret_dic = {}
     ret_dic['edit'] = False
     ret_dic['class_name'] = Obj._meta.object_name
+    field_updates = []
+    datalists = []
     if html_scripts:
         ret_dic['html_scripts'] = html_scripts
+    if treat_as_list:
+        for item in treat_as_list:
+            field_name = item['field_name']
+            action = item['action']
+            if action == 'text_to_choice':
+                datalists.append((field_name, Obj.objects.filter().values_list(\
+                        field_name, flat=True).distinct().order_by(field_name)))
+                field_updates.append((field_name, 'list', field_name))
+        if datalists:
+            ret_dic['datalists'] = datalists
     if request.method == 'POST':
         cancel = request.POST.get('cancel', '')
         if cancel:
@@ -82,11 +96,15 @@ def general_obj_new(request, Obj, ObjForm, translations={}, \
         else:
             ret_dic['form'] = apply_translations(\
                     ObjForm(request.POST, request=request), translations)
+            ret_dic['form'] = apply_field_updates(\
+                    ObjForm(request.POST, request=request), field_updates)
             return render(request, 'generalobj_new.html', \
                     ret_dic)
     else:
         ret_dic['form'] = apply_translations(ObjForm(request=request), \
                 translations)
+        ret_dic['form'] = apply_field_updates(ObjForm(request=request), \
+                field_updates)
         return render(request, 'generalobj_new.html', ret_dic)
 
     return HttpResponse('qqq')
